import { ISettingsParam, ILogObjMeta } from "./interfaces";
export * from "./interfaces";
export declare class BaseLogger<LogObj> {
    private logObj?;
    private stackDepthLevel;
    private readonly runtime;
    private readonly settings;
    private subLogger;
    constructor(settings?: ISettingsParam<LogObj>, logObj?: LogObj | undefined, stackDepthLevel?: number);
    /**
     * Logs a message with a custom log level.
     * @param logLevelId    - Log level ID e.g. 0
     * @param logLevelName  - Log level name e.g. silly
     * @param args          - Multiple log attributes that should be logged out.
     * @return LogObject with meta property
     */
    log(logLevelId: number, logLevelName: string, ...args: unknown[]): LogObj & ILogObjMeta;
    /**
     *  Attaches external Loggers, e.g. external log services, file system, database
     *
     * @param transportLogger - External logger to be attached. Must implement all log methods.
     * @param minLevel        - Minimum log level to be forwarded to this attached transport logger. (e.g. debug)
     */
    attachTransport(transportLogger: (transportLogger: LogObj & ILogObjMeta) => void): void;
    /**
     *  Returns a child logger based on the current instance with inherited settings
     *
     * @param settings - Overwrite settings inherited from parent logger
     */
    getSubLogger(settings?: ISettingsParam<LogObj>): BaseLogger<LogObj>;
    private _mask;
    private _maskValuesOfKeysRecursive;
    private _toLogObj;
    private _toErrorObject;
    private _addMetaToLogObj;
    private _prettyFormatLogObjMeta;
    private addMissingZeros;
}
